@@ -155,8 +155,10 @@ class AmiPipelineLib(
         id: builtins.str,
         pipeline_config: typing.Any,
         component_deps_config: typing.Sequence[typing.Any],
+        component_builder: "ComponentBuilder",
         *,
         channel: typing.Optional[builtins.str] = None,
+        extra_params: typing.Optional[typing.Sequence["ComponentParameter"]] = None,
         slack_webhook_url: typing.Optional[builtins.str] = None,
         username: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -166,15 +168,20 @@ class AmiPipelineLib(
         :param id: -
         :param pipeline_config: -
         :param component_deps_config: -
+        :param component_builder: -
         :param channel: 
+        :param extra_params: 
         :param slack_webhook_url: 
         :param username: 
         '''
-        slack_config = SlackConfiguration(
-            channel=channel, slack_webhook_url=slack_webhook_url, username=username
+        optional_params = AmiPipelineOptional(
+            channel=channel,
+            extra_params=extra_params,
+            slack_webhook_url=slack_webhook_url,
+            username=username,
         )
 
-        jsii.create(AmiPipelineLib, self, [scope, id, pipeline_config, component_deps_config, slack_config])
+        jsii.create(AmiPipelineLib, self, [scope, id, pipeline_config, component_deps_config, component_builder, optional_params])
 
     @jsii.member(jsii_name="createCleanerTask")
     def create_cleaner_task(self) -> None:
@@ -307,6 +314,18 @@ class AmiPipelineLib(
     def ebs_encryption_key(self, value: typing.Optional[aws_cdk.aws_kms.Key]) -> None:
         jsii.set(self, "ebsEncryptionKey", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="extraParameters")
+    def extra_parameters(self) -> typing.Optional[typing.List["ComponentParameter"]]:
+        return typing.cast(typing.Optional[typing.List["ComponentParameter"]], jsii.get(self, "extraParameters"))
+
+    @extra_parameters.setter
+    def extra_parameters(
+        self,
+        value: typing.Optional[typing.List["ComponentParameter"]],
+    ) -> None:
+        jsii.set(self, "extraParameters", value)
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="imagePipeline")
     def image_pipeline(
@@ -357,6 +376,73 @@ class AmiPipelineLib(
         jsii.set(self, "topic", value)
 
 
+@jsii.data_type(
+    jsii_type="halloumi-ami-pipelines.AmiPipelineOptional",
+    jsii_struct_bases=[],
+    name_mapping={
+        "channel": "channel",
+        "extra_params": "extraParams",
+        "slack_webhook_url": "slackWebhookUrl",
+        "username": "username",
+    },
+)
+class AmiPipelineOptional:
+    def __init__(
+        self,
+        *,
+        channel: typing.Optional[builtins.str] = None,
+        extra_params: typing.Optional[typing.Sequence["ComponentParameter"]] = None,
+        slack_webhook_url: typing.Optional[builtins.str] = None,
+        username: typing.Optional[builtins.str] = None,
+    ) -> None:
+        '''
+        :param channel: 
+        :param extra_params: 
+        :param slack_webhook_url: 
+        :param username: 
+        '''
+        self._values: typing.Dict[str, typing.Any] = {}
+        if channel is not None:
+            self._values["channel"] = channel
+        if extra_params is not None:
+            self._values["extra_params"] = extra_params
+        if slack_webhook_url is not None:
+            self._values["slack_webhook_url"] = slack_webhook_url
+        if username is not None:
+            self._values["username"] = username
+
+    @builtins.property
+    def channel(self) -> typing.Optional[builtins.str]:
+        result = self._values.get("channel")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def extra_params(self) -> typing.Optional[typing.List["ComponentParameter"]]:
+        result = self._values.get("extra_params")
+        return typing.cast(typing.Optional[typing.List["ComponentParameter"]], result)
+
+    @builtins.property
+    def slack_webhook_url(self) -> typing.Optional[builtins.str]:
+        result = self._values.get("slack_webhook_url")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def username(self) -> typing.Optional[builtins.str]:
+        result = self._values.get("username")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "AmiPipelineOptional(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 class ArnComponentRef(
     metaclass=jsii.JSIIMeta,
     jsii_type="halloumi-ami-pipelines.ArnComponentRef",
@@ -395,42 +481,12 @@ class ComponentBuilder(
         self,
         scope: aws_cdk.core.Construct,
         component_defs: typing.Sequence[typing.Any],
-        pipeline_name: builtins.str,
-        platform: builtins.str,
     ) -> None:
         '''
         :param scope: -
         :param component_defs: -
-        :param pipeline_name: -
-        :param platform: -
         '''
-        jsii.create(ComponentBuilder, self, [scope, component_defs, pipeline_name, platform])
-
-    @jsii.member(jsii_name="assembleComponent")
-    def assemble_component(
-        self,
-        component_config: typing.Any,
-        basedir: builtins.str,
-    ) -> typing.Any:
-        '''
-        :param component_config: -
-        :param basedir: -
-        '''
-        return typing.cast(typing.Any, jsii.invoke(self, "assembleComponent", [component_config, basedir]))
-
-    @jsii.member(jsii_name="createComponent")
-    def create_component(
-        self,
-        component_config: typing.Any,
-    ) -> typing.Optional[typing.Union[ArnComponentRef, aws_cdk.aws_imagebuilder.CfnComponent]]:
-        '''
-        :param component_config: -
-        '''
-        return typing.cast(typing.Optional[typing.Union[ArnComponentRef, aws_cdk.aws_imagebuilder.CfnComponent]], jsii.invoke(self, "createComponent", [component_config]))
-
-    @jsii.member(jsii_name="createComponentDependenciesMap")
-    def create_component_dependencies_map(self) -> "StringComponentMap":
-        return typing.cast("StringComponentMap", jsii.invoke(self, "createComponentDependenciesMap", []))
+        jsii.create(ComponentBuilder, self, [scope, component_defs])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cacheDir")
@@ -441,6 +497,20 @@ class ComponentBuilder(
     def cache_dir(self, value: builtins.str) -> None:
         jsii.set(self, "cacheDir", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="componentDependenciesMap")
+    def component_dependencies_map(
+        self,
+    ) -> typing.Mapping[builtins.str, typing.Union[ArnComponentRef, aws_cdk.aws_imagebuilder.CfnComponent]]:
+        return typing.cast(typing.Mapping[builtins.str, typing.Union[ArnComponentRef, aws_cdk.aws_imagebuilder.CfnComponent]], jsii.get(self, "componentDependenciesMap"))
+
+    @component_dependencies_map.setter
+    def component_dependencies_map(
+        self,
+        value: typing.Mapping[builtins.str, typing.Union[ArnComponentRef, aws_cdk.aws_imagebuilder.CfnComponent]],
+    ) -> None:
+        jsii.set(self, "componentDependenciesMap", value)
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="componentDeps")
     def component_deps(self) -> typing.List[typing.Any]:
@@ -450,24 +520,6 @@ class ComponentBuilder(
     def component_deps(self, value: typing.List[typing.Any]) -> None:
         jsii.set(self, "componentDeps", value)
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="pipelineName")
-    def pipeline_name(self) -> builtins.str:
-        return typing.cast(builtins.str, jsii.get(self, "pipelineName"))
-
-    @pipeline_name.setter
-    def pipeline_name(self, value: builtins.str) -> None:
-        jsii.set(self, "pipelineName", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="platform")
-    def platform(self) -> builtins.str:
-        return typing.cast(builtins.str, jsii.get(self, "platform"))
-
-    @platform.setter
-    def platform(self, value: builtins.str) -> None:
-        jsii.set(self, "platform", value)
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="scope")
     def scope(self) -> aws_cdk.core.Construct:
@@ -485,7 +537,7 @@ class ComponentBuilder(
         "branch": "branch",
         "name": "name",
         "path": "path",
-        "pipeline_name": "pipelineName",
+        "platform": "platform",
         "type": "type",
         "url": "url",
     },
@@ -497,7 +549,7 @@ class ComponentDependency:
         branch: builtins.str,
         name: builtins.str,
         path: builtins.str,
-        pipeline_name: builtins.str,
+        platform: builtins.str,
         type: builtins.str,
         url: builtins.str,
     ) -> None:
@@ -505,7 +557,7 @@ class ComponentDependency:
         :param branch: 
         :param name: 
         :param path: 
-        :param pipeline_name: 
+        :param platform: 
         :param type: 
         :param url: 
         '''
@@ -513,7 +565,7 @@ class ComponentDependency:
             "branch": branch,
             "name": name,
             "path": path,
-            "pipeline_name": pipeline_name,
+            "platform": platform,
             "type": type,
             "url": url,
         }
@@ -537,9 +589,9 @@ class ComponentDependency:
         return typing.cast(builtins.str, result)
 
     @builtins.property
-    def pipeline_name(self) -> builtins.str:
-        result = self._values.get("pipeline_name")
-        assert result is not None, "Required property 'pipeline_name' is missing"
+    def platform(self) -> builtins.str:
+        result = self._values.get("platform")
+        assert result is not None, "Required property 'platform' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
@@ -566,6 +618,51 @@ class ComponentDependency:
         )
 
 
+@jsii.data_type(
+    jsii_type="halloumi-ami-pipelines.ComponentParameter",
+    jsii_struct_bases=[],
+    name_mapping={"component_name": "componentName", "parameters": "parameters"},
+)
+class ComponentParameter:
+    def __init__(
+        self,
+        *,
+        component_name: builtins.str,
+        parameters: typing.Mapping[builtins.str, builtins.str],
+    ) -> None:
+        '''
+        :param component_name: 
+        :param parameters: 
+        '''
+        self._values: typing.Dict[str, typing.Any] = {
+            "component_name": component_name,
+            "parameters": parameters,
+        }
+
+    @builtins.property
+    def component_name(self) -> builtins.str:
+        result = self._values.get("component_name")
+        assert result is not None, "Required property 'component_name' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def parameters(self) -> typing.Mapping[builtins.str, builtins.str]:
+        result = self._values.get("parameters")
+        assert result is not None, "Required property 'parameters' is missing"
+        return typing.cast(typing.Mapping[builtins.str, builtins.str], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "ComponentParameter(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 class ComponentSynchronizer(
     metaclass=jsii.JSIIMeta,
     jsii_type="halloumi-ami-pipelines.ComponentSynchronizer",
@@ -852,9 +949,11 @@ class StringComponentMap:
 
 __all__ = [
     "AmiPipelineLib",
+    "AmiPipelineOptional",
     "ArnComponentRef",
     "ComponentBuilder",
     "ComponentDependency",
+    "ComponentParameter",
     "ComponentSynchronizer",
     "PipelineBuilder",
     "SlackConfiguration",
